Midnight Commander (c) 1995-2001, Free Software Foundation
Tip: C-x t vloží na příkazovou řádku označené soubory.
Tip: C-x p vloží na příkazovou řádku jméno aktuálního adresáře.
Tip: K doplňování použijte M-Tab (nebo Esc+Tab). Dvojitým zadání získáte seznam.
Tip: Použitím M-p nebo M-n se pohybujete v historii příkazů.
Tip: Chcete zadat speciální znak(např. tabelátor)? Použijte Ctrl-Q a daný znak.
Tip: Nechcete již vidět tipy? Vypněte je v Nastavení/Zobrazení/Další nastavení.
Tip: Adresáře vyberete přidáním lomítka na konec vzorku.
Tip: Pokud Váš terminál nezní nebo nemá funkční klávesy, použijte Esc+číslo.
Tip: Domácí stránka programu Midnight Commander je http://www.ibiblio.org/mc/
Tip: Zprávy o chybách posílejte na mc-devel@gnome.org (anglicky).
Tip: Pomocí klávesy Tab změníte aktuální panel.
Tip: Stiskem Enter na souboru .tar nebo .tar.gz si prohlédnete obsah.
Tip: Existuje také manuálová stránka [mc(1)].
Tip: Přejete si klávesy stejně jako v lynxu? Nastavte to v Nastavení.
Tip: Makra uvozená % pracují na příkazové řádce.
Tip: Pomocí M-! můžete spustit příkaz a prohlédnout si výstup v okně.
Tip: Zobrazení v panelech může být upraveno. Z 'man mc' se dozvíte více.
Tip: %D/%T se rozvine na soubory označené v druhém panelu.
Tip: Chcete opět váš shell? Stiskněte C-o. Do MC se vrátíte opět přes C-o.
Tip: Nastavením proměnné CDPATH můžete šetřit klávesnici.
Tip: Pokud chcete vidět soubory začínající tečkou, řekněte to v Nastavení.
Tip: Chcete vidět zálohy svých souborů (končí ~). Použijte Nastavení.
Tip: Doplňování funguje ve vstupních řádkách všech dialogů. Použijte M-Tab.
Tip: Na terminálech s pomalou odezvou skuste na parametr -s (mc -s).
Tip: S nalezenými soubory můžete pracovat. Stikněte tlačítko Panelizace.
Tip: Pro opravdu složité operace zkuste příkaz Příkaz/Externí panelizace.
Tip: Pokud chcete změnit adresář při práci na příkoazové řádce, zkuste M-c.
Poznámka: Příkazy shellu nefungují, pokud nepracujete na lokální systému souborů.
Tip: Smazaný text obnovíte C-y.
Tip: Pokud některé klávesy nefunfují, použijte menu Nastavení/učení kláves.
Tip: F13 (nebo Shift-F3) vyvolá prohlížení bez zpracování obsahu souboru.
Tip: Pokud v xtermu nepracují klávesy, zkuste soubory xterm.ad, .ti a .tcap.
Tip: Editor pro klávesu F4 určíte pomocí proměnné prostředí EDITOR.
Tip: Externí prohlížeč určíte proměnnou PAGER.
Tip: Všechny žádosti o potvrzení můžete zakázat v Nastavení/Potvrzování.
Tip: K seznam často používaných adresářů se můžete dostat i přes C-\.
Tip: Na anonymní FTP se připojíte pomocí 'cd /#ftp:stroj.domena.cz'
Tip: MC má vestavěný FTP protokol. Podívejte se do menu Levý/Ftp spojení.
Tip: M-t rychle mění formát zobrazení panelů.
Tip: Při FTP spojení můžete zadat i jméno: 'cd /#ftp:jmeno@stroj.domena.cz'
Tip: RPM soubory si prohlédnete stiskem Enter.
Tip: Pokud chcete označit adresář, přidejte '/' (lomítko).
Tip: Chcete-li použít myš pro zkopírování nebo vložení textu, stiskněte Shift.
Tip: V seznamu adresářů můžete mít i často navštěvované ftp servery. Zkuste C-\.
